Crate kcr_flow_volcano_sh

Crate kcr_flow_volcano_sh 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the flow.volcano.sh group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

flow.volcano.sh/v1alpha1

  • JobFlow
  • JobTemplate

Modules

v1alpha1